@@ -6,7 +6,6 @@ import pickle
 
 from strange_case.registry import Registry
 from strange_case.nodes import Node
-from strange_case.config_dict import ConfigDict
 from strange_case import strange_case
 
 
@@ -37,6 +36,7 @@ def run():
         'deploy_path',
         'remove_stale_files',
         'config_file',
+        'verbose',
     ]
     parser.add_argument('-x', '--exclude', nargs='*', dest='exclude_paths', default=None)
     parser.add_argument('-p', '--project', dest='project_path')
@@ -45,32 +45,44 @@ def run():
     parser.add_argument('-r', '--remove', dest='remove_stale_files', action='store_true', default=None)
     parser.add_argument('-n', '--no-remove', dest='remove_stale_files', action='store_false', default=None)
     parser.add_argument('-c', '--config', dest='config_file')
+    parser.add_argument('-v', '--verbose', dest='verbose', action='store_true', default=False)
     parser.add_argument('configs', nargs='*')
+    args = parser.parse_args()
+
+    if args.project_path:
+        if args.project_path[0] == '~':
+            project_path = os.path.expanduser(args.project_path)
+        else:
+            project_path = os.path.abspath(args.project_path)
+    else:
+        project_path = os.getcwd()
 
     # config section catches assertion errors and prints them as error messages
-    CONFIG = None
-    if os.path.isfile(os.path.join(os.getcwd(), 'config.py')):
-        config_module = imp.load_source('config', os.path.join(os.getcwd(), 'config.py'))
-        try:
-            CONFIG = config_module.CONFIG
-            if not isinstance(CONFIG, ConfigDict):
-                CONFIG = ConfigDict(CONFIG)
-        except AttributeError:
-            sys.stderr.write("Could not load CONFIG from config.py\n")
-            sys.exit(1)
+    from strange_case.strange_case_config import CONFIG
+    CONFIG['project_path'] = project_path
 
-    if CONFIG is None:
-        from strange_case.strange_case_config import CONFIG
+    if 'site_path' not in CONFIG:
+        CONFIG['site_path'] = os.path.join(project_path, u'site/')
+
+    if 'deploy_path' not in CONFIG:
+        CONFIG['deploy_path'] = os.path.join(project_path, u'public/')
 
     # normalize paths
-    for conf in ['project_path', 'site_path', 'deploy_path']:
+    for conf in ['site_path', 'deploy_path']:
         if CONFIG[conf][0] == '~':
             CONFIG[conf] = os.path.expanduser(CONFIG[conf])
         elif CONFIG[conf][0] == '.':
             CONFIG[conf] = os.path.abspath(CONFIG[conf])
 
     # now we can look for the app config
-    config_path = os.path.join(CONFIG['project_path'], CONFIG['config_file'])
+    if os.path.isfile(os.path.join(project_path, 'config.py')):
+        config_module = imp.load_source('config', os.path.join(project_path, 'config.py'))
+        try:
+            CONFIG.update(config_module.CONFIG)
+        except AttributeError:
+            sys.stderr.write("Could not load CONFIG from config.py\n")
+            sys.exit(1)
+    config_path = os.path.join(project_path, CONFIG['config_file'])
 
     if os.path.isfile(config_path):
         with open(config_path, 'r') as config_file:
@@ -78,7 +90,6 @@ def run():
         if yaml_config:
             CONFIG.update(yaml_config)
 
-    args = parser.parse_args()
     for conf in conf_overrides:
         if getattr(args, conf) is not None:
             CONFIG[conf] = getattr(args, conf)
@@ -150,6 +161,15 @@ def run():
         del CONFIG['processors']
 
     configurators = []
+    # load built-in pre configurators
+    for configurator in CONFIG['__configurators_pre__']:
+        if isinstance(configurator, basestring):
+            configurator = fancy_import(configurator)
+        configurators.append(configurator)
+        Registry.add_configurator(configurator)
+    del CONFIG['__configurators_pre__']
+
+    # load user configurators
     if 'configurators' in CONFIG:
         for configurator in CONFIG['configurators']:
             if isinstance(configurator, basestring):
@@ -158,8 +178,23 @@ def run():
             Registry.add_configurator(configurator)
         del CONFIG['configurators']
 
+    # load built-in post configurators
+    for configurator in CONFIG['__configurators_post__']:
+        if isinstance(configurator, basestring):
+            configurator = fancy_import(configurator)
+        configurators.append(configurator)
+        Registry.add_configurator(configurator)
+    del CONFIG['__configurators_post__']
+
     # additional configurators, in addition to the all-important defaults
     if 'configurators +' in CONFIG:
+        sys.error.write('''Built-in Configurators are now considered "protected",
+so the "configurators +" hack is no longer needed.
+
+However, you will probably want to make sure to include the defaults:
+- order_from_name
+- created_at_from_name
+- title_from_name''')
         for configurator in CONFIG['configurators +']:
             if isinstance(configurator, basestring):
                 configurator = fancy_import(configurator)
@@ -167,13 +202,6 @@ def run():
             Registry.add_configurator(configurator)
         del CONFIG['configurators +']
 
-    # additional file_types
-    for entry in Registry.file_types:
-        CONFIG['file_types'].append(entry)
-
-    if 'file_types +' in CONFIG:
-        CONFIG['file_types'].extend(CONFIG['file_types +'])
-
     # read timestamps file
     timestamps_file = os.path.join(CONFIG['project_path'], '.timestamps')
     if os.path.exists(timestamps_file):
@@ -211,7 +239,7 @@ def run():
 
         observer = Observer()
         handler = Regenerate()
-        for path in os.listdir(os.getcwd()):
+        for path in os.listdir(project_path):
             path = os.path.abspath(path)
             if os.path.isdir(path) and path not in exclude_paths:
                 sys.stderr.write('Watching "%s" for changes\n' % path)
