@@ -2,14 +2,20 @@ import os
 from fnmatch import fnmatch
 
 from strange_case.configurators import provides
+from strange_case.registry import Registry
 
 
 @provides('type')
 def file_types(source_file, config):
     if os.path.isdir(source_file):
-        config['type'] = 'folder'
+        config['type'] = config['default_folder_type']
         return config
     else:
+        types = config.get('file_types', [])
+        # built-in file_types
+        for entry in Registry.file_types:
+            types.append(entry)
+
         file_name = os.path.basename(source_file)
         for node_type, globs in config.get('file_types', []):
             if isinstance(globs, basestring):
@@ -22,3 +28,15 @@ def file_types(source_file, config):
             return None
         config['type'] = config['default_type']
         return config
+
+file_types.defaults = {
+    'file_types': [
+        ('page', ('*.j2', '*.jinja2', '*.jinja', '*.txt', '*.html', '*.xml')),
+    ],
+    'default_type': 'asset',
+    'default_folder_type': 'folder',
+}
+
+file_types.require_after = [
+    'type',
+]
